// Swing-Komponenten sind im Package javax.swing
import javax.swing.JFrame;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;

// LayoutManager und sind im Package java.awt
import java.awt.BorderLayout;
import java.awt.GridLayout;

public class Swing5{

	public static void main(String[] args){
		// JFrame (unsichtbar) erzeugen mit einem Titel.
		JFrame jfMain = new JFrame("Hier steht der Titel");
		
		// Aktion setzen, die ausgefuehrt wird, wenn auf das
		// 'x' in der Titelleiste geklickt wird.
		// Hier wird das Fenster nicht nur verborgen (hide)
		// sondern komplett entfernt (dispose).
		jfMain.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);

		// JButton erzeugen mit vorgegebenem Text.
		JButton jbSouth = new JButton("Drueck mich!");

		// JPanel als Container fuer ein Gitter von Buttons
		// LayoutManager GridLayout erzeugt ein Gitter von
		// (hier) 2x2 Flaechen, die alle gleich gross sind.
		JPanel jpCenter = new JPanel(new GridLayout(2,2));
		for(int i=1; i<=4; ++i){
			// Jeweils neuen Button erzeugen mit 
			// aktuellem Zaehler-Wert als Text.
			JButton jbTmp = new JButton(""+i);
			// GridLayout ordnet Komponenten zeilenweise an,
			// daher ist der zweite Parameter nicht notwendig.
			jpCenter.add(jbTmp);
		}
		
		// JLabel erzeugen mit zentriertem Text.
		JLabel jlNorth = new JLabel("Hallo Welt", JLabel.CENTER);

		// JPanel als oberster Container fuer Label, Button
		// und das Gitter von Buttons in der Mitte.
		// Als Layout wird das BorderLayout verwendet,
		// das die Anordnung der Komponenten uebernimmt.
		JPanel jpContent = new JPanel(new BorderLayout());
		// Die einzelnen Komponenten hinzufuegen.
		// Der zweite Parameter ist abhaeging vom LayoutManager.
		// Hier fuer das BorderLayout NORTH, CENTER und SOUTH.
		jpContent.add(jlNorth, BorderLayout.NORTH);
		jpContent.add(jpCenter, BorderLayout.CENTER);
		jpContent.add(jbSouth, BorderLayout.SOUTH);

		// Panel als Inhalt (ContentPane) setzen.
		jfMain.setContentPane(jpContent);

		// Optimale Groesse des Fensters automatisch bestimmen.
		// (Anhand der bevorzugten Dimensionen der Inhaltskomponenten)
		jfMain.pack();

		// JFrame anzeigen (sichtbar machen).	
		jfMain.setVisible(true);
		
		// Das Programm laeuft hier direkt weiter und beendet
		// sich nicht, da das erzeugt Fenster noch existiert!
		System.out.println("JFrame mit mehreren Komponenten wurde erzeugt");
	}
}
