// Swing-Komponenten sind im Package javax.swing
import javax.swing.JFrame;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;

// LayoutManager und sind im Package java.awt
import java.awt.BorderLayout;
import java.awt.GridLayout;

// Klassen fuer das Eventhandling sind im Package java.awt.event
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

// Die Klasse implementiert ActionListener
// -> die Methode actionPerformed muss also existieren!
public class Swing8 implements ActionListener{
	// Globales Attribut der Klasse Frame8
	private JButton jbSouth;

	public Swing8(){
		// JFrame (unsichtbar) erzeugen mit einem Titel.
		JFrame jfMain = new JFrame("Hier steht der Titel");
		
		// Aktion setzen, die ausgefuehrt wird, wenn auf das
		// 'x' in der Titelleiste geklickt wird.
		// Hier wird das Fenster nicht nur verborgen (hide)
		// sondern komplett entfernt (dispose).
		jfMain.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);

		// JButton erzeugen mit vorgegebenem Text.
		jbSouth = new JButton("Drueck mich!");
		
		// Listener bei Button registrieren
		// Als ActionListener wird das aktuelle Objekt
		// mitgegeben, also das erzeugte Objekt der Klasse
		// Swing8.
		jbSouth.addActionListener(this);
		
		// JLabel erzeugen mit zentriertem Text.
		JLabel jlNorth = new JLabel("Hallo Welt", JLabel.CENTER);

		// JPanel als oberster Container fuer Label und Button
		// Als Layout wird das BorderLayout verwendet,
		// das die Anordnung der Komponenten uebernimmt.
		JPanel jpContent = new JPanel(new BorderLayout());
		// Die einzelnen Komponenten hinzufuegen.
		// Der zweite Parameter ist abhaeging vom LayoutManager.
		// Hier fuer das BorderLayout NORTH und SOUTH.
		jpContent.add(jlNorth, BorderLayout.NORTH);
		jpContent.add(jbSouth, BorderLayout.SOUTH);

		// Panel als Inhalt (ContentPane) setzen.
		jfMain.setContentPane(jpContent);

		// Optimale Groesse des Fensters automatisch bestimmen.
		// (Anhand der bevorzugten Dimensionen der Inhaltskomponenten)
		jfMain.pack();
		
		// JFrame anzeigen (sichtbar machen).	
		jfMain.setVisible(true);
	}

	// Definierte Methode des Interfaces ActionListener
	// Diese wird bei allen registrierten Listenern
	// aufgerufen, wenn ein Ereignis (Event) eintritt.
	public void actionPerformed(ActionEvent e){
		// Pruefen ob das Event von einem bestimmten Button kam
		if(e.getSource()==jbSouth){
			System.out.println("Event kam von Button 'jbSouth'");
		}	
	}

	public static void main(String[] args){
		// Objekt der Klasse Swing8 erzeugen 
		// -> Konstruktor wird aufgerufen!
		Swing8 s = new Swing8();
		
		// Das Programm laeuft hier direkt weiter und beendet
		// sich nicht, da das erzeugt Fenster noch existiert!
		System.out.println("JFrame mit mehreren Komponenten wurde erzeugt");
	}
}
