// Swing-Komponenten sind im Package javax.swing
import javax.swing.JFrame;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;

// LayoutManager und sind im Package java.awt
import java.awt.BorderLayout;
import java.awt.GridLayout;

// Klassen fuer das Eventhandling sind im Package java.awt.event
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

// Die Klasse Color liegt im Package java.awt
import java.awt.Color;

// Die Klasse implementiert ActionListener
// -> die Methode actionPerformed muss also existieren!
public class Swing9 implements ActionListener{
	
	public Swing9(){
		// JFrame (unsichtbar) erzeugen mit einem Titel.
		JFrame jfMain = new JFrame("Hier steht der Titel");
		
		// Aktion setzen, die ausgefuehrt wird, wenn auf das
		// 'x' in der Titelleiste geklickt wird.
		// Hier wird das Fenster nicht nur verborgen (hide)
		// sondern komplett entfernt (dispose).
		jfMain.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);

		// JButton erzeugen mit vorgegebenem Text.
		JButton jbSouth = new JButton("Drueck mich!");
		
		// Listener bei Button registrieren
		// Als ActionListener wird das aktuelle Objekt
		// mitgegeben, also das erzeugte Objekt der Klasse
		// Swing9.
		jbSouth.addActionListener(this);
		
		// JLabel erzeugen mit zentriertem Text.
		JLabel jlNorth = new JLabel("Hallo Welt", JLabel.CENTER);

		// JPanel als oberster Container fuer Label und Button
		// Als Layout wird das BorderLayout verwendet,
		// das die Anordnung der Komponenten uebernimmt.
		JPanel jpContent = new JPanel(new BorderLayout());
		// Die einzelnen Komponenten hinzufuegen.
		// Der zweite Parameter ist abhaeging vom LayoutManager.
		// Hier fuer das BorderLayout NORTH und SOUTH.
		jpContent.add(jlNorth, BorderLayout.NORTH);
		jpContent.add(jbSouth, BorderLayout.SOUTH);

		// Panel als Inhalt (ContentPane) setzen.
		jfMain.setContentPane(jpContent);

		// Optimale Groesse des Fensters automatisch bestimmen.
		// (Anhand der bevorzugten Dimensionen der Inhaltskomponenten)
		jfMain.pack();
		
		// JFrame anzeigen (sichtbar machen).	
		jfMain.setVisible(true);
	}

	// Definierte Methode des Interfaces ActionListener
	// Diese wird bei allen registrierten Listenern
	// aufgerufen, wenn ein Ereignis (Event) eintritt.
	public void actionPerformed(ActionEvent e){
		// Pruefen ob das Event von einem Button kam
		// instanceof liefert true, wenn hinter e.getSource()
		// ein Objekt der Klasse JButton liegt!
		if(e.getSource() instanceof JButton){
			System.out.println("Event kam von einem JButton");
			// Typzusicherung (type-cast) 
			// e.getSource() liefert ein Object, aber dahinter
			// verbirgt sich polymorph ein JButton.
			// Deshalb kann nach dem type-cast auf getText() etc.
			// zugegriffen werden.
			JButton jbTmp = (JButton)e.getSource();
			// jbTmp ist eine Referenz auf den Button jbSouth
			// -> daher greifen wir hier auf die Attribute von jbSouth zu.
			String text = jbTmp.getText();
			// Text des Buttons ausgeben
			System.out.println(text);
			// Dem Button einen neuen Text geben und die Hintergrundfarbe aendern.
			jbTmp.setText("Gedrueckt");
			jbTmp.setBackground(Color.RED);
		}	
	}

	public static void main(String[] args){
		// Objekt der Klasse Swing9 erzeugen 
		// -> Konstruktor wird aufgerufen!
		Swing9 s = new Swing9();
		
		// Das Programm laeuft hier direkt weiter und beendet
		// sich nicht, da das erzeugt Fenster noch existiert!
		System.out.println("JFrame mit mehreren Komponenten wurde erzeugt");
	}
}
